;; Generated package description from seq.el  -*- no-byte-compile: t -*-
(define-package "seq" "2.23.0.20221221.82021" "Sequence manipulation functions" 'nil :commit "e86379d2cb8f59458d7027a5e1d0e79585b14391" :url "https://elpa.gnu.org/packages/seq.html" :authors '(("Nicolas Petton" . "nicolas@petton.fr")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("sequences"))
